@@ -257,13 +257,7 @@ static gpointer open_thread(gpointer data)
 
 int sample_open_file(const char *filename, GraphData *graphData, double *pct)
 {
-    if (sample_file != NULL) {
-        free(sample_file);
-        sample_file = NULL;
-    }
-    if (read_sample_fp != NULL) {
-        sample_close_file();
-    }
+    sample_close_file();
 
     sample_file = strdup(filename);
 
@@ -301,11 +295,15 @@ int sample_open_file(const char *filename, GraphData *graphData, double *pct)
 
 void sample_close_file()
 {
-    fclose(read_sample_fp);
-    read_sample_fp = NULL;
+    if( read_sample_fp != NULL) {
+        fclose( read_sample_fp);
+        read_sample_fp = NULL;
+    }
 
-    free(sample_file);
-    sample_file = NULL;
+    if( sample_file != NULL) {
+        free( sample_file);
+        sample_file = NULL;
+    }
 } 
 
 static void sample_max_min(GraphData *graphData, double *pct)
@@ -313,6 +311,7 @@ static void sample_max_min(GraphData *graphData, double *pct)
     int tmp = 0;
     int ret = 0;
     int min, max;
+    int min_sample, max_sample;
     int i, k;
     int numSampleBlocks;
     double tmp_sample_calc;
@@ -350,6 +349,9 @@ static void sample_max_min(GraphData *graphData, double *pct)
             BLOCK_SIZE * i);
     }
 
+    min_sample = SHRT_MAX; /* highest value for 16-bit samples */
+    max_sample = 0;
+
     while (ret == BLOCK_SIZE) {
         min = max = 0;
         for (k = 0; k < ret; k++) {
@@ -374,6 +376,13 @@ static void sample_max_min(GraphData *graphData, double *pct)
         graph_data[i].min = min;
         graph_data[i].max = max;
 
+        if( min_sample > (max-min)) {
+            min_sample = (max-min);
+        }
+        if( max_sample < (max-min)) {
+            max_sample = (max-min);
+        }
+
         if (audio_type == CDDA) {
             ret = cdda_read_sample(read_sample_fp, devbuf, BLOCK_SIZE,
                     BLOCK_SIZE * i);
@@ -395,6 +404,9 @@ static void sample_max_min(GraphData *graphData, double *pct)
     }
     graphData->data = graph_data;
 
+    graphData->minSampleAmp = min_sample;
+    graphData->maxSampleAmp = max_sample;
+
     if (sampleInfo.bitsPerSample == 8) {
         graphData->maxSampleValue = UCHAR_MAX;
     } else if (sampleInfo.bitsPerSample == 16) {
