@@ -1,5 +1,5 @@
 /* wavbreaker - A tool to split a wave file up into multiple wave.
- * Copyright (C) 2002 Timothy Robinson
+ * Copyright (C) 2002-2005 Timothy Robinson
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 #include "wavbreaker.h"
 
-#define BUF_SIZE 4096
+#define DEFAULT_BUF_SIZE 4096
 #define BLOCK_SIZE 2352
 
 #define CD_BLOCK_SIZE                   (2352)
@@ -30,15 +30,17 @@
 typedef struct SampleInfo_ SampleInfo;
 
 struct SampleInfo_ {
-		unsigned short	channels;
-		unsigned long	samplesPerSec;
-		unsigned long	avgBytesPerSec;
-		unsigned short	blockAlign;
-		unsigned short	bitsPerSample;
-		unsigned long	numBytes;
+    unsigned short  channels;
+    unsigned int    samplesPerSec;
+    unsigned int    avgBytesPerSec;
+    unsigned short  blockAlign;
+    unsigned short  bitsPerSample;
+    unsigned int    numBytes;
+    unsigned int    bufferSize;
 };
 
 char *wav_get_error_message();
+char *sample_get_error_message();
 
 void sample_init();
 void sample_set_audio_dev(char *str);
@@ -46,10 +48,13 @@ char * sample_get_audio_dev();
 
 char * sample_get_sample_file();
 
+int sample_is_playing();
 int play_sample(gulong, gulong *);
 void stop_sample();
 int sample_open_file(const char *, GraphData *, double *);
-void sample_write_files(const char *, GList *, WriteInfo *);
+void sample_close_file();
+void sample_write_files(GList *, WriteInfo *, char *);
 gint sample_get_playing();
+void sample_merge_files(char *merge_filename, GList *filenames, WriteInfo *write_info);
 
 #endif /* SAMPLE_H*/
